@@ -2,18 +2,22 @@
 from django.contrib.syndication.feeds import Feed
 from django.core.urlresolvers import reverse
 from django.utils.feedgenerator import Atom1Feed
+from django.utils.html import strip_tags
 
 from mezzanine.blog.models import BlogPost
-from mezzanine.settings import BLOG_TITLE, BLOG_DESCRIPTION
+from mezzanine.blog.views import blog_page
 
 
 class PostsRSS(Feed):
     """
     RSS feed for all blog posts.
     """
+    
+    def title(self):
+        return blog_page().title
 
-    title = BLOG_TITLE
-    description = BLOG_DESCRIPTION
+    def description(self):
+        return strip_tags(blog_page().description)
 
     def link(self):
         return reverse("blog_post_feed", kwargs={"url": "rss"})
@@ -28,7 +32,9 @@ class PostsAtom(PostsRSS):
     """
 
     feed_type = Atom1Feed
-    subtitle = PostsRSS.description
+    
+    def subtitle(self):
+        return self.description()
 
     def link(self):
         return reverse("blog_post_feed", kwargs={"url": "atom"})
