@@ -24,12 +24,12 @@ def _page_menu(context, parent_page):
             user = context["request"].user
         except KeyError:
             user = None
+        try:
+            slug = context["request"].path.strip("/")
+        except KeyError:
+            slug = ""
         for page in Page.objects.published(for_user=user).order_by("_order"):
-            try:
-                slug = context["request"].path.strip("/")
-            except KeyError:
-                slug = ""
-            setattr(page, "selected", slug.startswith(page.slug))
+            setattr(page, "selected", (slug + "/").startswith(page.slug + "/"))
             setattr(page, "primary", page.parent_id is None)
             pages[page.parent_id].append(page)
         context["menu_pages"] = pages
@@ -90,7 +90,7 @@ def models_for_pages(*args):
     """
     page_models = []
     for model in get_models():
-        if issubclass(model, Page):
+        if model is not Page and issubclass(model, Page):
             setattr(model, "name", model._meta.verbose_name)
             setattr(model, "add_url", reverse("admin:%s_%s_add" %
                 (model._meta.app_label, model.__name__.lower())))
