@@ -80,7 +80,7 @@ else:
 # Store these package names here as they may change in the future since at the
 # moment we are using custom forks of them.
 PACKAGE_NAME_FILEBROWSER = "filebrowser_safe"
-PACKAGE_NAME_GRAPPELLI = "grappelli_ssafe"
+PACKAGE_NAME_GRAPPELLI = "grappelli_safe"
 
 # Optional apps.
 OPTIONAL_APPS = (
